@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: decoding.cc,v $
-// Revision      : $Revision: 1.25 $
-// Revision date : $Date: 2006/01/15 23:12:58 $
+// Revision      : $Revision: 1.28 $
+// Revision date : $Date: 2006/09/03 14:33:02 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : Various functions for decoding, converting ...
 //
@@ -785,13 +785,16 @@ std::string
 Decoding::decrypt_aes (const std::string &passphrase, const std::string &data)
 {
 #ifdef HAVE_AES
+	unsigned char *phraseptr = (unsigned char *)passphrase.c_str ();
+	guint phraselen = passphrase.size();
+
 	// Check Passphrase
-	if (passphrase.size() < 16)
+	if (phraselen < 16)
 		return std::string ("");
 
 	// Determine size and allocate memory
 	guint size = data.size()/2;
-	if (size == 0)
+	if ((size == 0) || (size%16 != 0))
 		return std::string ("");
 	unsigned char *bin = new unsigned char[size+1];
 	if (!bin)
@@ -808,8 +811,12 @@ Decoding::decrypt_aes (const std::string &passphrase, const std::string &data)
 
 	// Decrypt via AES
 	AES_KEY aes_key;
-	AES_set_decrypt_key ((unsigned char *)passphrase.c_str (), 128, &aes_key);
-	AES_decrypt (bin, result, &aes_key);
+	for (guint i = 0, j = 0; i < size; i+=16) {
+		AES_set_decrypt_key (phraseptr + j, 128, &aes_key);
+		AES_decrypt (bin + i, result + i, &aes_key);
+		if (++j > phraselen - 16)
+			j = 0;
+	}
 
 	// Free memory
 	std::string result_str = std::string ((char *)result);
@@ -839,13 +846,16 @@ Decoding::encrypt_aes (const std::string &passphrase, const std::string &data)
 {
 #ifdef HAVE_AES
 	const char hex[] = "0123456789ABCDEF";
+	unsigned char *dataptr = (unsigned char *)data.c_str ();
+	unsigned char *phraseptr = (unsigned char *)passphrase.c_str ();
+	guint phraselen = passphrase.size();
 
 	// Check Passphrase
-	if (passphrase.size() < 16)
+	if (phraselen < 16)
 		return std::string ("");
 
 	// Determine size and allocate memory
-	guint size = (data.size()+15)/16*16;
+	guint size = (data.size()+16)/16*16;
 	if (size == 0)
 		return std::string ("");
 	unsigned char *result = new unsigned char[2*size];
@@ -854,8 +864,12 @@ Decoding::encrypt_aes (const std::string &passphrase, const std::string &data)
 
 	// Encrypt via AES
 	AES_KEY aes_key;
-	AES_set_encrypt_key ((unsigned char *)passphrase.c_str (), 128, &aes_key);
-	AES_encrypt ((unsigned char *)data.c_str (), result, &aes_key);
+	for (guint i = 0, j = 0; i < size; i += 16) {
+		AES_set_encrypt_key (phraseptr + j, 128, &aes_key);
+		AES_encrypt (dataptr + i, result + i, &aes_key);
+		if (++j > phraselen - 16)
+			j = 0;
+	}
 
 	// Binary to ASCII
 	for (guint i = size; i > 0; i--) {
