@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: decoding.h,v $
-// Revision      : $Revision: 1.16 $
-// Revision date : $Date: 2005/04/25 23:20:25 $
+// Revision      : $Revision: 1.20 $
+// Revision date : $Date: 2006/01/15 21:40:42 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : Various functions for decoding, converting ...
 //
@@ -35,6 +35,15 @@
 #ifdef HAVE_CONFIG_H
 #   include <config.h>
 #endif
+
+#ifdef HAVE_AES
+#   ifdef HAVE_LIBSSL
+#       include <openssl/aes.h>
+#   elif HAVE_LIBCRYPTO
+#       include <crypto/aes.h>
+#   endif
+#endif
+
 #include <glib.h>
 #include <string>
 #include <vector>
@@ -66,24 +75,29 @@ protected:
 
 	// Encodings
 	std::string decode_base64 (const std::string &);
+	std::string decode_base64 (const std::vector<std::string> &,
+							   std::string::size_type pos = 0);
 	std::string decode_qencoding (const std::string &);
 	std::string decode_quotedprintable (const std::string &);
 	std::vector<std::string> decode_quotedprintable (
 				const std::vector<std::string> &,
-				std::string::size_type pos=0);
+				std::string::size_type pos = 0);
 
 	// Converting
 	std::string utf8_to_imaputf7 (std::string str);
 	gchar* utf8_to_imaputf7 (const gchar *, gssize);
 	std::string ascii_strdown (const std::string &str);
-	gchar *charset_to_utf8 (std::string text, std::string charset);
+	gchar *charset_to_utf8 (std::string text, std::string charset,
+							guint retries = 0);
 
 public:
-	// Password
-	static std::string encrypt_password (const std::string &password,
-										 const std::string &passtable);
-	static std::string decrypt_password (const std::string &password,
-										 const std::string &passtable);
+	// Decryption/Encryption
+	static std::string decrypt_password_legacy (const std::string &passphrase,
+												const std::string &password);
+	static std::string decrypt_aes (const std::string &passphrase,
+									const std::string &data);
+	static std::string encrypt_aes (const std::string &passphrase,
+									const std::string &data);
 };
 
 #endif
