@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: file.cc,v $
-// Revision      : $Revision: 1.17 $
-// Revision date : $Date: 2005/04/13 16:10:08 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.19 $
+// Revision date : $Date: 2006/01/01 16:44:52 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -146,8 +146,6 @@ void File::fetch (void) throw (local_err)
 		// Get all pending FAM events. This is necassary because calling utime
 		// causes FAM events. It may result in some new mails not being
 		// noticed because of race conditions.
-		while (FAMPending(&fam_connection_))
-			if (FAMNextEvent (&fam_connection_, &fam_event_)<0)
-				break;
+		fam_get_all_pending_events ();
 	}
 }
