@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: gnubiff_options.h,v $
-// Revision      : $Revision: 1.5 $
-// Revision date : $Date: 2005/04/07 14:46:53 $
+// Revision      : $Revision: 1.11 $
+// Revision date : $Date: 2006/03/11 23:23:52 $
 // Author(s)     : Robert Sowada, Nicolas Rougier
 // Short         : Options for gnubiff
 //
@@ -45,8 +45,10 @@
 const guint	MANUAL_CHECK		=	0;
 const guint	AUTOMATIC_CHECK		=	1;
 
-const guint	GTK_MODE			=	0;
-const guint	GNOME_MODE			=	1;
+const guint	MODE_GTK			=	0;
+const guint	MODE_GNOME			=	1;
+const guint MODE_NOGUI			=   2;
+const guint MODE_SYSTEMTRAY		=   3;
 
 const guint	PROTOCOL_NONE		=	0;
 const guint	PROTOCOL_FILE		=	1;
@@ -73,6 +75,14 @@ const guint	MAILBOX_CHECK		=	4;
 const guint	MAILBOX_STOP		=	5;
 const guint	MAILBOX_UNKNOWN		=	6;
 
+const guint SIGNAL_NONE			=   0;
+const guint SIGNAL_MARK_AS_READ	=   1;
+const guint SIGNAL_START		=	2;
+const guint SIGNAL_STOP			=	3;
+const guint SIGNAL_POPUP_ENABLE	=	4;
+const guint SIGNAL_POPUP_DISABLE=	5;
+const guint SIGNAL_POPUP_TOGGLE =	6;
+
 const guint OPTGRP_GENERAL		=	1;
 const guint OPTGRP_APPLET		=	2;
 const guint OPTGRP_POPUP		=	4;
@@ -83,14 +93,16 @@ const guint OPTGRP_SECURITY		=	32;
 class Gnubiff_Options : public Options {
 public:
 protected:
-	void add_options (guint groups);
-	void add_options_applet (void);
-	void add_options_general (void);
-	void add_options_information (void);
-	void add_options_mailbox (void);
-	void add_options_popup (void);
-	void add_options_security (void);
+	void add_options (guint groups, gboolean deprecated = false);
+
 private:
+	void add_options_applet (gboolean deprecated);
+	void add_options_general (gboolean deprecated);
+	void add_options_information (gboolean deprecated);
+	void add_options_mailbox (gboolean deprecated);
+	void add_options_popup (gboolean deprecated);
+	void add_options_security (gboolean deprecated);
+
 	const static guint protocol_int[];
 	const static gchar *protocol_gchar[];
 };
