@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: gui.h,v $
-// Revision      : $Revision: 1.4 $
-// Revision date : $Date: 2005/04/04 22:08:28 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.6 $
+// Revision date : $Date: 2006/01/01 16:44:52 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -53,7 +53,7 @@ public:
 	virtual ~GUI (void);
 
 	/* main */
-	virtual gint create (void);
+	virtual gint create (gpointer callbackdata);
 	void create_insert_version (void);
 	virtual void show (std::string name = "dialog");
 	virtual void hide (std::string name = "dialog");
