@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: mailbox.cc,v $
-// Revision      : $Revision: 1.87 $
-// Revision date : $Date: 2006/02/03 22:41:20 $
+// Revision      : $Revision: 1.92 $
+// Revision date : $Date: 2006/09/03 18:44:30 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -30,6 +30,8 @@
 // ========================================================================
 
 #include <algorithm>
+#include <sys/types.h>
+#include <regex.h>
 #include "support.h"
 #include "mailbox.h"
 #include "file.h"
@@ -57,6 +59,11 @@ Mailbox::Mailbox (Biff *biff)
 	biff_ = biff;
 	listed_ = false;
 	stopped_ = false;
+	timetag_ = 0;
+
+	// Create mutexes
+	mutex_ = g_mutex_new ();
+	monitor_mutex_ = g_mutex_new ();
 
 	// Add options
 	add_options (OPTGRP_MAILBOX, !biff_->value_bool ("config_file_loaded"));
@@ -64,9 +71,8 @@ Mailbox::Mailbox (Biff *biff)
 	// Set session specific options
 	value ("uin", uin_count_++);
 
-	timetag_ = 0;
-	mutex_ = g_mutex_new ();
-	monitor_mutex_ = g_mutex_new ();
+	// Setup regular expressions for filtering messages
+	filter_create ();
 }
 
 Mailbox::Mailbox (const Mailbox &other)
@@ -94,9 +100,13 @@ Mailbox::operator= (const Mailbox &other)
 
 Mailbox::~Mailbox (void)
 {
+	// Free compiled regular expressions
 	g_mutex_lock (mutex_);
+	filter_free ();
+	g_mutex_unlock (mutex_);
+
+	// Free all mutexes
 	g_mutex_unlock (mutex_);
-	g_mutex_free (mutex_);
 	g_mutex_lock (monitor_mutex_);
 	g_mutex_unlock (monitor_mutex_);
 	g_mutex_free (monitor_mutex_);
@@ -311,6 +321,12 @@ Mailbox::option_changed (Option *option)
 		}
 		return;
 	}
+
+	// FILTER_LOCAL
+	if (option->name() == "filter_local") {
+		filter_create ();
+		return;
+	}
 }
 
 /**
@@ -584,22 +600,26 @@ Mailbox::lookup_local (Mailbox &oldmailbox)
  *  it can be given to this functions via the optional parameters {\em pi} and
  *  {\em hh}.
  *
- *  @param mail  Message line by line in a vector of strings
- *  @param uid   Unique identifier of the mail (if known), the default is an
- *               empty string.
- *  @param pi    PartInfo structure with information about the first part of
- *               the mail (if known), the default is NULL.
- *  @param hh    Header with retrieved information about the message (if
- *               known), the default is NULL.
- *  @param pos   Number of the first line in the array to be parsed. This is
- *               needed to easily parse multipart messages recusively. The
- *               default is 0.
+ *  @param mail   Message line by line in a vector of strings
+ *  @param uid    Unique identifier of the mail (if known), the default is an
+ *                empty string.
+ *  @param pi     PartInfo structure with information about the first part of
+ *                the mail (if known), the default is NULL.
+ *  @param hh     Header with retrieved information about the message (if
+ *                known), the default is NULL.
+ *  @param pos    Number of the first line in the array to be parsed. This is
+ *                needed to easily parse multipart messages recusively. The
+ *                default is 0.
+ *  @param status Default status of the message. If this is set to false the
+ *                message will not be stored. This option is needed for
+ *                multipart messages that are parsed recursivly (The default is
+ *                true).
  */
 void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
-					 PartInfo *pi, Header *hh, guint pos)
+					 PartInfo *pi, Header *hh, guint pos, gboolean status)
 {
 	Header h;
-	gboolean status = true; // set to false if mail should not be stored
+	gboolean getstatus = true;
 	guint len = mail.size ();
 	PartInfo partinfo;
 
@@ -641,7 +661,9 @@ void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
 					   || (mail[pos+1].at(0) == '\t')))
  				line += mail[++pos];
 
-		std::string line_down = ascii_strdown (line);
+		// Filter header line using stored regular expression
+		if (getstatus)
+			getstatus = !filter_match_line (line, status);
 
 		// Sender, Subject, Date:
 		// There should be a whitespace (space or tab) after "From:",
@@ -694,14 +716,6 @@ void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
 				continue;
 			}
 		}
-
-		// Status
-	    if (line.find ("Status: R") == 0)
-			status = false;
-		else if (line.find ("X-Mozilla-Status: 0001") == 0)
-			status = false;
-		else if (line_down.find ("x-spam-flag: yes") == 0)
-			status = false;
 	}
 
 	// Charset
@@ -770,7 +784,7 @@ void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
 			partinfo.parameters_.clear ();
 
 			// Parse first part of multipart message
-			parse (mail, uid, &partinfo, &h, saved_pos);
+			parse (mail, uid, &partinfo, &h, saved_pos, status);
 
 			// No need to parse rest of mail
 			return;
@@ -804,29 +818,27 @@ void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
 	// If there is an error message put it into the body
 	h.error_to_body ();
 
+	// Set unique message identifier
+	h.mailid (uid);
+
 	// Store mail depending on status
 	if (status) {
-		// Pines trick
-		if (h.subject().find("DON'T DELETE THIS MESSAGE -- FOLDER INTERNAL DATA") == std::string::npos) {
-			// Ok, at this point mail is
-			//  - not a spam
-			//  - has not been read (R or 0001 status flag)
-			//  - is not a special header (see above)
-			// so we have to decide what to do with it because we may have already displayed it
-			// and maybe it has been gnubifficaly marked as "seen".
-			//
-			h.mailid (uid);
-			if (hidden_.find (h.mailid()) == hidden_.end ()) {
-				h.position (new_unread_.size() + 1);
-				h.mailbox_uin (value_uint ("uin"));
-				new_unread_[h.mailid()] = h;
-			}
-			new_seen_.insert (h.mailid());
-#ifdef DEBUG
-			g_message ("[%d] Parsed mail with id \"%s\"", uin(),
-					   h.mailid().c_str ());
-#endif
+		// Message was not filtered because of regular expressions and is
+		// not marked as seen, so it will be stored now
+		if (hidden_.find (h.mailid()) == hidden_.end ()) {
+			h.position (new_unread_.size() + 1);
+			h.mailbox_uin (value_uint ("uin"));
+			new_unread_[h.mailid()] = h;
 		}
+		new_seen_.insert (h.mailid());
+#ifdef DEBUG
+		g_message ("[%d] Parsed message with id \"%s\"", uin(),
+				   h.mailid().c_str ());
+	}
+	else {
+		g_message ("[%d] Parsed and discarded message with id \"%s\"", uin(),
+				   h.mailid().c_str ());
+#endif
 	}
 }
 
@@ -1131,3 +1143,147 @@ Mailbox::get_message_headers (std::vector<Header *> &headers,
 
 	g_mutex_unlock (mutex_);
 }
+
+// ============================================================================
+//  filtering
+// ============================================================================
+
+/**
+ *  Compile some regular expressions and add them to those already
+ *  used for filtering messages by header lines in this mailbox. The
+ *  new expressions are applied after those already in existance.
+ *
+ *  Format of the expressions: Each expression has to be prefixed by
+ *  "+" or "-". Messages matching a "+"-expression are displayed,
+ *  messages matching a "-"-expression are ignored. The "+" or "-" may
+ *  be preceded by " "I" for case insensitive pattern matching.
+ *
+ *  @param  regex  Vector of the regular expressions as described above.
+ *  @return        Boolean indicating success (i.e. all expressions could
+ *                 be compiled successfully)
+ */
+gboolean 
+Mailbox::filter_add (std::vector<std::string> &regex_strs)
+{
+	unsigned int			num = regex_strs.size ();
+	std::string::size_type	pos, len, errlen;
+	gboolean				okay = true;
+	int						cflags, errcode;
+	regex_t					*regex;
+
+	for (unsigned int i = 0; i < num; i++) {
+		// Find "+" or "-"
+		len = regex_strs[i].length ();
+		pos = 0;
+		while ((pos < len)
+			   && (regex_strs[i][pos] != '+') && (regex_strs[i][pos] != '-'))
+			pos++;
+		if (pos == len) {
+			okay = false;
+			continue;
+		}
+
+		// Case sensitivity
+		cflags = REG_EXTENDED | REG_NOSUB;
+		if (regex_strs[i].substr(0, pos).find("I") != std::string::npos)
+			cflags |= REG_ICASE;
+
+		// Compile expression
+		regex = new regex_t;
+		errcode = regcomp (regex,
+						   regex_strs[i].substr(pos+1, len-pos-1).c_str(),
+						   cflags);
+
+		// Add compiled expression
+		if (!errcode) {
+			filter_regex_.push_back (regex);
+			filter_opts_.push_back (regex_strs[i].substr(0, pos+1));
+			continue;
+		}
+
+		// Error message
+		errlen = regerror (errcode, regex, NULL, 0);
+		gchar *buffer = new gchar[errlen];
+		regerror (errcode, regex, buffer, errlen);
+		g_message (_("Error when compiling a regular expression.\n"
+					 "Regular expression: %s\n"
+					 "Error message: %s"),
+				   regex_strs[i].substr(pos+1, len-pos-1).c_str(), buffer);
+		delete buffer;
+	}
+
+	return okay;
+}
+
+/**
+ *  Compile the regular expressions used for filtering messages by header
+ *  lines in this mailbox. The compiled expressions are stored for later use,
+ *  any compiled expressions that are already stored are freed.
+ *
+ *  @return Boolean indicating success
+ */
+gboolean 
+Mailbox::filter_create (void)
+{
+	gboolean ok = true;
+	g_mutex_lock (mutex_);
+
+	// Free existing compiled expressions
+	filter_free ();
+
+	// Compile expressions in the correct order
+	std::vector<std::string> regex;
+	ok = biff_->get_values ("filter_global_first", regex, true);
+	ok = get_values ("filter_local", regex, false) && ok;
+	ok = biff_->get_values ("filter_global_last", regex, false) && ok;
+	filter_add (regex);
+
+	g_mutex_unlock (mutex_);
+
+	return ok;
+}
+
+/**
+ *  Free all existing compiled regular expressions used for filtering messages
+ *  by header lines in this mailbox.
+ */
+void 
+Mailbox::filter_free (void)
+{
+	unsigned int num = filter_regex_.size ();
+
+	for (unsigned int i = 0; i < num; i++) {
+		regfree (filter_regex_[i]);
+		delete filter_regex_[i];
+	}
+
+	filter_regex_.clear ();
+	filter_opts_.clear ();
+}
+
+/**
+ *  Match the string {\em line} with the stored regular expressions.
+ *
+ *  @param  line   Line to be matched
+ *  @param  status If the return value is true this parameter indicates
+ *                 whether the message shall be shown or not.
+ *  @return        True if {\em status} was set by this function call, false
+ *                 otherwise.
+ */
+gboolean 
+Mailbox::filter_match_line (std::string line, gboolean &status)
+{
+	unsigned int num = filter_regex_.size ();
+
+	for (unsigned int i = 0; i < num; i++) {
+		if (!(regexec (filter_regex_[i],line.c_str (), 0, NULL, 0))) {
+			if (filter_opts_[i].find ("+") != std::string::npos)
+				status = true;
+			else
+				status = false;
+			return true;
+		}
+	}
+
+	return false;
+}
