@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: pop.cc,v $
-// Revision      : $Revision: 1.30 $
-// Revision date : $Date: 2005/08/07 14:28:23 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.34 $
+// Revision date : $Date: 2006/02/03 22:41:20 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -35,7 +35,6 @@
 #include <utime.h>
 
 #include "ui-applet.h"
-#include "ui-popup.h"
 #include "pop.h"
 #include "socket.h"
 #include "nls.h"
@@ -116,17 +115,13 @@ Pop::start (void) throw (pop_err)
 #if DEBUG
 		g_warning ("[%d] Pop exception: %s", uin(), err.what());
 #endif
-		status (MAILBOX_ERROR);
-		unread_.clear ();
-		seen_.clear ();
+		set_status_mailbox_error ();
 		socket_->close ();
 	}
 
-	if (!GTK_WIDGET_VISIBLE (biff_->popup()->get())) {
-		gdk_threads_enter();
-		biff_->applet()->update();
-		gdk_threads_leave();
-	}
+	gdk_threads_enter ();
+	biff_->applet()->update ();
+	gdk_threads_leave ();
 
 	g_mutex_unlock (monitor_mutex_);
 
@@ -153,7 +148,7 @@ void
 Pop::fetch (void) throw (pop_err)
 {
 	// Is there a password? Can we obtain it?
-	if (!biff_->password(this)) {
+	if (!biff_->get_password_for_mailbox (this)) {
 		g_warning (_("[%d] Empty password"), uin());
 		throw pop_nologin_err();
 	}
