@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: support.h,v $
-// Revision      : $Revision: 1.12.2.1 $
-// Revision date : $Date: 2005/12/04 20:05:04 $
+// Revision      : $Revision: 1.16 $
+// Revision date : $Date: 2006/01/07 22:43:34 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : Support functions
 //
@@ -76,7 +76,8 @@ public:
 
 	// Debugging
 	static void unknown_internal_error_ (const gchar *file, guint line,
-				const gchar *func);
+										 const gchar *func,
+										 const gchar *signal);
 };
 
 /**
@@ -139,6 +140,6 @@ Support::vector_to_numbersequence (Iter start, Iter end, const std::string sep,
  *  Print debug information. This function should be called in a situation
  *  that should never happen to provide more information in a bug report.
  */
-#define unknown_internal_error() (Support::unknown_internal_error_ (__FILE__, __LINE__, __func__))
+#define unknown_internal_error() (Support::unknown_internal_error_ (__FILE__, __LINE__, __func__, ""))
 
 #endif
