@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2004 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet.h,v $
-// Revision      : $Revision: 1.3 $
-// Revision date : $Date: 2004/12/04 20:38:22 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.24 $
+// Revision date : $Date: 2006/03/12 21:10:29 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -32,37 +32,43 @@
 #ifndef __APPLET_H__
 #define __APPLET_H__
 
-#include "gui.h"
-#include "biff.h"
-
-
-class Applet : public GUI {
+#include <glib.h>
+#include "support.h"
 
+/**
+ *  Generic non-GUI code common for all types of applets.
+ */ 
+class Applet : public Support
+{
 protected:
 	class Biff *		biff_;
 	GMutex *			process_mutex_;
 	GMutex *			update_mutex_;
-	gboolean			force_popup_;
-
 public:
 	// ========================================================================
 	//  base
-	// ========================================================================	
-	Applet (class Biff *biff,
-			std::string filename);
+	// ========================================================================
+	Applet (class Biff *biff);
 	virtual ~Applet (void);
+	virtual void start (gboolean showpref = false);
 
 	// ========================================================================
 	//  main
-	// ========================================================================	
-	void start (guint delay=0);						// start monitoring
-	void stop  (void);								// stop monitoring
-	virtual void update (gboolean no_popup = false);// update applet
-	virtual void dock (GtkWidget *applet) {};		// dock applet
-
-	guint       unread_markup (std::string &text);	// build unread markup string
-	std::string tooltip_text (void);				// build tooltip text
+	// ========================================================================
+	virtual gboolean update (gboolean init = false);
+	void mark_messages_as_read (void);
+	void execute_command (std::string option_command,
+						  std::string option_use_command = "");
+	std::string get_mailbox_status_text (void);
+	virtual std::string get_number_of_unread_messages (void);
 
+	/// @see AppletGUI::mailbox_to_be_replaced ()
+	virtual void mailbox_to_be_replaced (class Mailbox *from,
+										 class Mailbox *to) {};
+	/// @see AppletGUI::get_password_for_mailbox ()
+	virtual void get_password_for_mailbox (class Mailbox *mb) {};
+	virtual gboolean can_monitor_mailboxes (void);
+	virtual void enable_popup (gboolean enable);
 };
 
 #endif
