@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2005 Nicolas Rougier
+// Copyright (c) 2000-2006 Nicolas Rougier, 2004-2006 Robert Sowada
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,9 +19,9 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-preferences.cc,v $
-// Revision      : $Revision: 1.44 $
-// Revision date : $Date: 2005/07/17 14:28:28 $
-// Author(s)     : Nicolas Rougier
+// Revision      : $Revision: 1.55 $
+// Revision date : $Date: 2006/01/01 16:44:53 $
+// Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
 // This file is part of gnubiff.
@@ -33,7 +33,7 @@
 
 #include "ui-preferences.h"
 #include "ui-properties.h"
-#include "ui-applet.h"
+#include "ui-applet-gui.h"
 #include "gtk_image_animation.h"
 #include "biff.h"
 #include "mailbox.h"
@@ -230,7 +230,7 @@ Preferences::Preferences (Biff *biff) : GUI (GNUBIFF_DATADIR"/preferences.glade"
 {
 	biff_ = biff;
 	properties_ = new Properties (this);
-	properties_->create ();
+	properties_->create (properties_);
 	selected_ = 0;
 	added_ = 0;
 	// Widgets
@@ -245,9 +245,9 @@ Preferences::~Preferences (void)
 }
 
 gint
-Preferences::create (void)
+Preferences::create (gpointer callbackdata)
 {
-	GUI::create ();
+	GUI::create (this);
 
 	// Create expert tab
 	expert_create ();
@@ -397,23 +397,44 @@ Preferences::expert_create (void)
 	expert_add_option_list ();
 }
 
-void
+/**
+ *  Show the preferences dialog.
+ *
+ *  @param  name  Widget's name of the dialog. The default is "dialog".
+ */
+void 
 Preferences::show (std::string name)
 {
+	// Is glade file okay?
 	if (!xml_)
 		return;
+
+	// Update all widgets and texts in the dialog
 	synchronize ();
-	biff_->applet()->stop ();
+
 	gtk_widget_show (get(name));
 }
 
-void Preferences:: hide (std::string name) {
+/**
+ *  Hide the preferences dialog.
+ *
+ *  @param  name  Widget's name of the dialog. The default is "dialog".
+ */
+void 
+Preferences::hide (std::string name)
+{
+	// Is the glade file okay?
 	if (!xml_)
 		return;
+
+	// Hide the properties dialog
+	if (properties_)
+		properties_->hide ();
+
+	// Hide the preferences dialog
 	gtk_widget_hide (get(name));
 }
 
-
 void 
 Preferences::synchronize (class Mailbox *mailbox, GtkListStore *store, GtkTreeIter *iter)
 {
@@ -458,7 +479,7 @@ Preferences::synchronize (void)
 	// Mailboxes list
 	GtkTreeView  *view  = GTK_TREE_VIEW (get("mailboxes_treeview"));
 	GtkListStore *store = GTK_LIST_STORE (gtk_tree_view_get_model (view));
-	for (guint i=0; i<biff_->size(); i++)
+	for (guint i=0; i < biff_->get_number_of_mailboxes (); i++)
 		biff_->mailbox(i)->listed (false);
 	GtkTreeIter iter;
 	gboolean valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(store), &iter);
@@ -475,7 +496,7 @@ Preferences::synchronize (void)
 			valid = gtk_list_store_remove (store, &iter);
 	}
 
-	for (guint i=0; i<biff_->size(); i++) {
+	for (guint i=0; i < biff_->get_number_of_mailboxes (); i++) {
 		Mailbox *mailbox = biff_->mailbox(i);
 		if (!mailbox->listed()) {
 			gtk_list_store_append (store, &iter);
@@ -518,7 +539,7 @@ Preferences::on_add	(GtkWidget *widget)
 		if (selected_)
 			(*added_) = (*selected_);
 
-		biff_->add (added_);
+		biff_->add_mailbox (added_);
 		synchronize ();
 		GtkTreeView  *view  = GTK_TREE_VIEW (get("mailboxes_treeview"));
 		GtkTreeIter iter;
@@ -546,7 +567,7 @@ Preferences::on_remove (GtkWidget *widget)
 		GtkListStore *store = GTK_LIST_STORE (gtk_tree_view_get_model (view));
 		guint uin;
 		gtk_tree_model_get (GTK_TREE_MODEL(store), &iter, COLUMN_UIN, &uin, -1);
-		biff_->remove (biff_->get(uin));
+		biff_->remove_mailbox (biff_->get(uin));
 		properties_->select (0);
 		synchronize ();
 	}	
@@ -559,21 +580,21 @@ Preferences::on_properties (GtkWidget *widget)
 		properties_->show();
 }
 
-void
+/**
+ *  This function is called when the preferences dialog shall be closed. Before
+ *  hiding the dialog the changes are applied and saved.
+ *
+ *  @param widget  Unused parameter.
+ */
+void 
 Preferences::on_close (GtkWidget *widget)
 {
-
-	// Hide properties
-	properties_->hide ();
-
-	// Apply change & save them
+	// Apply changes and save them
 	apply ();
 	biff_->save ();
-	hide();
-	if (biff_->value_uint ("check_mode") == AUTOMATIC_CHECK)
-		biff_->applet()->start (3);
-	biff_->applet()->update(true);
-	biff_->applet()->show();
+
+	// Hide the preferences dialog
+	((AppletGUI *)biff_->applet())->hide_dialog_preferences();
 }
 
 
@@ -614,25 +635,36 @@ Preferences::on_browse_nomail_image (GtkWidget *widget)
 	browse (_("Browse for a new mail image"), "nomail_image_entry", false, preview);
 }
 
-gboolean
-Preferences::on_destroy (GtkWidget *widget,  GdkEvent *event)
+/**
+ *  This function is called when the preferences dialog has been destroyed.
+ *
+ *  @param  widget Unused parameter.
+ *  @param  event  Unused parameter.
+ *  @return        Always true is returned.
+ */
+gboolean 
+Preferences::on_destroy (GtkWidget *widget, GdkEvent *event)
 {
-	hide ();
-	if (biff_->value_uint ("check_mode") == AUTOMATIC_CHECK)
-		biff_->applet()->start (3);
-	biff_->applet()->update(true);
-	biff_->applet()->show();
+	// Hide the preferences dialog
+	((AppletGUI *)biff_->applet())->hide_dialog_preferences();
+
 	return true;
 }
 
-gboolean
-Preferences::on_delete (GtkWidget *widget,  GdkEvent *event)
+/**
+ *  This function is called when there is a request to delete the preferences
+ *  dialog. 
+ *
+ *  @param  widget Unused parameter.
+ *  @param  event  Unused parameter.
+ *  @return        Always true is returned.
+ */
+gboolean 
+Preferences::on_delete (GtkWidget *widget, GdkEvent *event)
 {
-	hide ();
-	if (biff_->value_uint ("check_mode") == AUTOMATIC_CHECK)
-		biff_->applet()->start (3);
-	biff_->applet()->update(true);
-	biff_->applet()->show();
+	// Hide the preferences dialog
+	((AppletGUI *)biff_->applet())->hide_dialog_preferences();
+
 	return true;
 }
 
@@ -754,7 +786,7 @@ Preferences::expert_add_option_list (void)
 	std::map<std::string, Option *>::iterator it;
 
 	// Add options
-	for (int i = -1; i < (signed)biff_->size(); i++) {
+	for (int i = -1; i < (signed)biff_->get_number_of_mailboxes (); i++) {
 		if (i == -1)
 			opts = biff_;
 		else
@@ -808,6 +840,8 @@ Preferences::expert_add_option_list (void)
 void 
 Preferences::expert_on_selection (GtkTreeSelection *selection)
 {
+	std::string tmpstr;
+
 	// Get option
 	Options *opts;
 	Option *option;
@@ -822,12 +856,14 @@ Preferences::expert_on_selection (GtkTreeSelection *selection)
 	gtk_text_buffer_get_start_iter (tb, &iter);
 	gtk_text_buffer_insert (tb, &iter, "Option ", -1);
 	tmp = option->name().c_str();
-	gtk_text_buffer_insert_with_tags_by_name (tb, &iter, tmp, -1, "bold", 0);
+	gtk_text_buffer_insert_with_tags_by_name (tb, &iter, tmp, -1, "bold",
+											  NULL);
 	gtk_text_buffer_insert (tb, &iter, ": ", -1);
 	gtk_text_buffer_insert (tb, &iter, option->help().c_str(), -1);
 	gtk_text_buffer_insert (tb, &iter, "\n\nGroup ", -1);
 	tmp = opts->group_name(option->group()).c_str();
-	gtk_text_buffer_insert_with_tags_by_name (tb, &iter, tmp, -1, "bold", 0);
+	gtk_text_buffer_insert_with_tags_by_name (tb, &iter, tmp, -1, "bold",
+											  NULL);
 	gtk_text_buffer_insert (tb, &iter, ": ", -1);
 	tmp = opts->group_help(option->group()).c_str();
 	gtk_text_buffer_insert (tb, &iter, tmp, -1);
@@ -835,18 +871,20 @@ Preferences::expert_on_selection (GtkTreeSelection *selection)
 	gtk_text_buffer_insert (tb, &iter, option->default_string().c_str(), -1);
 	if (option->type () == OPTTYPE_UINT) {
 		gtk_text_buffer_insert (tb, &iter, "\n\nAllowed values: ", -1);
-		tmp = ((Option_UInt *)option)->allowed_ids (", ").c_str();
+		tmpstr = ((Option_UInt *)option)->allowed_ids (", ");
+		tmp = tmpstr.c_str ();
 		gtk_text_buffer_insert (tb, &iter, tmp, -1);
 		if (!(option->flags () & OPTFLG_ID_INT_STRICT)) {
 			if (*tmp)
 				gtk_text_buffer_insert (tb, &iter, ", ", -1);
 			tmp = "any positive integer";
 			gtk_text_buffer_insert_with_tags_by_name (tb, &iter, tmp, -1,
-													  "italic", 0);
+													  "italic", NULL);
 		}
 	}
 	gtk_text_buffer_insert (tb, &iter, "\n\nProperties: ", -1);
-	tmp = option->flags_string().c_str();
+	tmpstr = option->flags_string ();
+	tmp = tmpstr.c_str ();
 	gtk_text_buffer_insert (tb, &iter, tmp, -1);
 }
 
